@@ -5,7 +5,11 @@ extends 'NewsExtractor::GenericExtractor';
 
 sub journalist {
     my ($self) = @_;
-    my ($txt) = $self->content_text =~ m{（記者／(\p{Letter}+)）\z};
+    my $content_text = $self->content_text;
+    my ($txt) = $content_text =~ m{（記者／(\p{Letter}+)）\z};
+    unless ($txt) {
+        ($txt) = $content_text =~ m{\n（(中國時報／.+)）\z};
+    }
     return $txt;
 }
 
